# PostPublicEmailTemplateRequestEncodingType

The endcode type of the email body.

## Enum

* `UTF8` (value: `'UTF8'`)

* `SHIFT_JIS` (value: `'Shift_JIS'`)

* `ISO_2022_JP` (value: `'ISO_2022_JP'`)

* `EUC_JP` (value: `'EUC_JP'`)

* `X_SJIS_0213` (value: `'X_SJIS_0213'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


